Common subdirectories: oggenc.orig/.deps and oggenc/.deps
Common subdirectories: oggenc.orig/CVS and oggenc/CVS
diff -u oggenc.orig/encode.h oggenc/encode.h
--- oggenc.orig/encode.h	Sat Aug 11 06:06:27 2001
+++ oggenc/encode.h	Sat Aug 11 14:58:18 2001
@@ -52,6 +52,8 @@
 	int raw_channels;
 
 	char *namefmt;
+	char *namefmt_remove;
+	char *namefmt_replace;
 	char *outfile;
 	int kbps;
 	unsigned int serial;
Common subdirectories: oggenc.orig/man and oggenc/man
diff -u oggenc.orig/oggenc.c oggenc/oggenc.c
--- oggenc.orig/oggenc.c	Sat Aug 11 03:59:45 2001
+++ oggenc/oggenc.c	Sat Aug 11 15:07:45 2001
@@ -33,6 +33,8 @@
 	{"album",1,0,'l'},
 	{"title",1,0,'t'},
 	{"names",1,0,'n'},
+	{"name-remove",1,0,'M'},
+	{"name-replace",1,0,'P'},
 	{"output",1,0,'o'},
 	{"version",0,0,'v'},
 	{"raw",0,0,'r'},
@@ -47,7 +49,7 @@
 	{NULL,0,0,0}
 };
 	
-char *generate_name_string(char *format, char *artist, char *title, char *album, char *track, char *date);
+char *generate_name_string(char *format, char *remove_list, char *replace_list, char *artist, char *title, char *album, char *track, char *date);
 void parse_options(int argc, char **argv, oe_options *opt);
 void build_comments(vorbis_comment *vc, oe_options *opt, int filenum, 
 		char **artist, char **album, char **title, char **tracknum, char **date);
@@ -56,7 +58,7 @@
 int main(int argc, char **argv)
 {
 	oe_options opt = {"ISO-8859-1", NULL, 0, NULL, 0, NULL, 0, NULL, 0, NULL, 
-		0, NULL, 0, 0, 0,16,44100,2, NULL,NULL,128,0}; /* Default values */
+		0, NULL, 0, 0, 0,16,44100,2, NULL,NULL,NULL,NULL,128,0}; /* Default values */
 	int i;
 
 	char **infiles;
@@ -193,7 +195,7 @@
 			}
 			else if(opt.namefmt)
 			{
-				out_fn = generate_name_string(opt.namefmt, artist, title, album, track,date);
+				out_fn = generate_name_string(opt.namefmt, opt.namefmt_remove, opt.namefmt_replace, artist, title, album, track,date);
 			}
 			else if(opt.title)
 			{
@@ -292,6 +294,14 @@
 		"                      %%n, %%d replaces by artist, title, album, track number,\n"
 		"                      and date, respectively (see below for specifying these).\n"
 		"                      %%%% gives a literal %%.\n"
+		" -M, --name-remove=string\n"
+		"                      Removed the specified characters from parameters to the\n"
+		"                      -n format to ensure legal filenames.\n"
+		" -P, --name-replace=string\n"
+		"                      Replace characters removed by -M with the characters\n"
+		"                      specified.  If the -P list is shorter than the -M list,\n"
+		"                      or if -P is not specified, the excess characters will\n"
+		"                      simply be removed.\n"
 		" -c, --comment=c      Add the given string as an extra comment. This may be\n"
 		"                      used multiple times.\n"
 		" -d, --date           Date for track (usually date of performance)\n"
@@ -331,7 +341,29 @@
 		" ~70kbps file, not 112kbps.)\n");
 }
 
-char *generate_name_string(char *format, 
+static void strcpyfiltered(char *dst, char *src, char *remove_list, char *replace_list)
+{
+	char *hit, *drop_margin;
+
+	if (remove_list == NULL || *remove_list == '\0')
+		strcpy(dst, src);
+
+	drop_margin = remove_list + (replace_list == NULL ? 0 : strlen(replace_list));
+
+	while (*src)
+	{
+		if ((hit = strchr(remove_list, *src)) != NULL)
+		{
+			if (hit < drop_margin)
+				*dst++ = replace_list[hit - remove_list];
+		}
+		else
+			*dst++ = *src;
+		src++;
+	}
+	*dst = '\0';
+}
+char *generate_name_string(char *format, char *remove_list, char *replace_list,
 		char *artist, char *title, char *album, char *track, char *date)
 {
 	char *buffer;
@@ -355,29 +387,25 @@
 					*cur++ = '%';
 					break;
 				case 'a':
-					strcat(buffer, artist?artist:"(none)");
-					cur += strlen(artist?artist:"(none)");
+					strcpyfiltered(cur, artist?artist:"(none)", remove_list, replace_list);
 					break;
 				case 'd':
-					strcat(buffer, date?date:"(none)");
-					cur += strlen(date?date:"(none)");
+					strcpyfiltered(cur, date?date:"(none)", remove_list, replace_list);
 					break;
 				case 't':
-					strcat(buffer, title?title:"(none)");
-					cur += strlen(title?title:"(none)");
+					strcpyfiltered(cur, title?title:"(none)", remove_list, replace_list);
 					break;
 				case 'l':
-					strcat(buffer, album?album:"(none)");
-					cur += strlen(album?album:"(none)");
+					strcpyfiltered(cur, album?album:"(none)", remove_list, replace_list);
 					break;
 				case 'n':
-					strcat(buffer, track?track:"(none)");
-					cur += strlen(track?track:"(none)");
+					strcpyfiltered(cur, track?track:"(none)", remove_list, replace_list);
 					break;
 				default:
 					fprintf(stderr, "WARNING: Ignoring illegal escape character '%c' in name format\n", *(format - 1));
 					break;
 			}
+			cur = strchr(cur, '\0');
 		}
 		else
 			*cur++ = next;
@@ -391,7 +419,7 @@
 	int ret;
 	int option_index = 1;
 
-	while((ret = getopt_long(argc, argv, "a:b:B:c:C:d:e:hl:n:N:o:qrR:s:t:v", 
+	while((ret = getopt_long(argc, argv, "a:b:B:c:C:d:e:hl:M:n:N:o:P:qrR:s:t:v", 
 					long_options, &option_index)) != -1)
 	{
 		switch(ret)
@@ -439,6 +467,22 @@
 					free(opt->namefmt);
 				}
 				opt->namefmt = strdup(optarg);
+				break;
+			case 'M':
+				if(opt->namefmt_remove)
+				{
+					fprintf(stderr, "WARNING: Multiple name format filters specified, using final\n");
+					free(opt->namefmt_remove);
+				}
+				opt->namefmt_remove = strdup(optarg);
+				break;
+			case 'P':
+				if(opt->namefmt_replace)
+				{
+					fprintf(stderr, "WARNING: Multiple name format filter replacements specified, using final\n");
+					free(opt->namefmt_replace);
+				}
+				opt->namefmt_replace = strdup(optarg);
 				break;
 			case 'o':
 				if(opt->outfile)

